@@ -95,16 +95,6 @@ class ResultRegistryTests(TestCase):
         self.assertTrue(ResultRegistry.stop.synchronized)
         self.assertTrue(ResultRegistry.register.synchronized)
 
-    def test_shutdown(self):
-        """
-        The ResultRegistry registers an after shutdown call to self.stop() in
-        the given reactor.
-        """
-        reactor = FakeReactor()
-        registry = ResultRegistry(reactor)
-        self.assertEqual(reactor.events,
-                         [("after", "shutdown", registry.stop)])
-
 
 class EventualResultTests(TestCase):
     """
@@ -381,6 +371,40 @@ try:
     er.wait(timeout=10)
 except crochet.ReactorStopped:
     sys.exit(23)
+"""
+        process = subprocess.Popen([sys.executable, "-c", program])
+        self.assertEqual(process.wait(), 23)
+
+    def test_reactor_stop_unblocks_EventualResult_in_threadpool(self):
+        """
+        Any EventualResult.wait() calls still waiting when the reactor has
+        stopped will get a ReactorStopped exception, even if it is running in
+        Twisted's thread pool.
+        """
+        program = """\
+import os, threading, signal, time, sys
+
+from twisted.internet.defer import Deferred
+from twisted.internet import reactor
+
+import crochet
+crochet.setup()
+
+@crochet.run_in_reactor
+def run():
+    reactor.callLater(0.1, reactor.stop)
+    return Deferred()
+
+result = [13]
+def inthread():
+    er = run()
+    try:
+        er.wait(timeout=10)
+    except crochet.ReactorStopped:
+        result[0] = 23
+reactor.callInThread(inthread)
+time.sleep(1)
+sys.exit(result[0])
 """
         process = subprocess.Popen([sys.executable, "-c", program])
         self.assertEqual(process.wait(), 23)
@@ -748,10 +772,20 @@ except crochet.ReactorStopped:
         process = subprocess.Popen([sys.executable, "-c", program])
         self.assertEqual(process.wait(), 23)
 
+
 class PublicAPITests(TestCase):
     """
     Tests for the public API.
     """
+    def test_no_sideeffects(self):
+        """
+        Creating an EventLoop object, as is done in crochet.__init__, does not
+        call any methods on the objects it is created with.
+        """
+        c = EventLoop(None, lambda f, g: 1/0, lambda *args: 1/0,
+                      watchdog_thread=object(), reapAllProcesses=lambda: 1/0)
+        del c
+
     def test_eventloop_api(self):
         """
         An EventLoop object configured with the real reactor and
