@@ -5,7 +5,7 @@ A flask web application that downloads a page in the background.
 
 import logging
 from flask import Flask, session, escape
-from crochet import setup, in_reactor, retrieve_result, TimeoutError
+from crochet import setup, run_in_reactor, retrieve_result, TimeoutError
 
 # Can be called multiple times with no ill-effect:
 setup()
@@ -13,8 +13,8 @@ setup()
 app = Flask(__name__)
 
 
-@in_reactor
-def download_page(reactor, url):
+@run_in_reactor
+def download_page(url):
     """
     Download a page.
     """
@@ -25,11 +25,13 @@ def download_page(reactor, url):
 @app.route('/')
 def index():
     if 'download' not in session:
-        # No download, start it in background:
-        session['download'] = download_page('http://www.google.com').stash()
+        # Calling an @run_in_reactor function returns an EventualResult:
+        result = download_page('http://www.google.com')
+        session['download'] = result.stash()
         return "Starting download, refresh to track progress."
 
-    # retrieval is a one-time operation, so session value cannot be reused:
+    # Retrieval is a one-time operation, so the uid in the session cannot be
+    # reused:
     result = retrieve_result(session.pop('download'))
     try:
         download = result.wait(timeout=0.1)
